Coverage for src/paperap/tests/factories/__init__.py: 100%

1"""

2

3

4

5 ----------------------------------------------------------------------------

6

7 METADATA:

8

9 File: __init__.py

10 Project: paperap

11 Created: 2025-03-07

12 Version: 0.0.5

13 Author: Jess Mann

14 Email: jess@jmann.me

15 Copyright (c) 2025 Jess Mann

16

17 ----------------------------------------------------------------------------

18

19 LAST MODIFIED:

20

21 2025-03-07 By Jess Mann

22

23"""

24

25 from paperap.tests.factories.models import (CorrespondentFactory,

26 CustomFieldFactory,

27 DocumentFactory, DocumentNoteFactory,

28 DocumentTypeFactory, GroupFactory,

29 ProfileFactory, PydanticFactory,

30 SavedViewFactory,

31 ShareLinksFactory,

32 StoragePathFactory, TagFactory,

33 TaskFactory, UISettingsFactory,

34 UserFactory, WorkflowActionFactory,

35 WorkflowFactory,

36 WorkflowTriggerFactory)